formview — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# formview

form view

class `camelot.view.controls.formview.` `FormEditors`(columns, widget_mapper, delegate, admin)

  A class that holds the editors used on a form

  `create_editor`(field_name, parent)

    Returns: | a `QtGuiQWidget` or None if field_name is unknown

class `camelot.view.controls.formview.` `FormView`(title, admin, model, index)

  A FormView is the combination of a FormWidget, possible actions and menu items

  view

  `form_widget`

    alias of `FormWidget`

  `refresh`()

    Refresh the data in the current view

  `toHtml`(*args, **kwargs)

    generates html of the form

  `viewFirst`()

    select model’s first row

  `viewLast`()

    select model’s last row

  `viewNext`()

    select model’s next row

  `viewPrevious`()

    select model’s previous row

class `camelot.view.controls.formview.` `FormWidget`(parent, admin)

  A form widget comes inside a form view or inside an embedded manytoone editor

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus